@@ -46,7 +46,7 @@ citation_impute <- function(
   additional = NULL
 ) {
 
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
 
   rank <- as.integer(rank)
 
